Enum snarkvm_r1cs::errors::SynthesisError
source · pub enum SynthesisError {
AnyhowError(Error),
AssignmentMissing,
ConstraintFieldError(ConstraintFieldError),
DivisionByZero,
Unsatisfiable,
PolynomialDegreeTooLarge,
UnexpectedIdentity,
IoError(Error),
MalformedVerifyingKey(usize, usize),
UnconstrainedVariable,
}Expand description
This is an error that could occur during circuit synthesis contexts, such as CRS generation, proving or verification.
Variants
AnyhowError(Error)
AssignmentMissing
During synthesis, we lacked knowledge of a variable assignment.
ConstraintFieldError(ConstraintFieldError)
Handles a failed conversion of objects into constraint field elements.
DivisionByZero
During synthesis, we divided by zero.
Unsatisfiable
During synthesis, we constructed an unsatisfiable constraint system.
PolynomialDegreeTooLarge
During synthesis, our polynomials ended up being too high of degree
UnexpectedIdentity
During proof generation, we encountered an identity in the CRS
IoError(Error)
During proof generation, we encountered an I/O error with the CRS
MalformedVerifyingKey(usize, usize)
During verification, our verifying key was malformed.
UnconstrainedVariable
During CRS generation, we observed an unconstrained auxiliary variable